import os
import sys
import shutil
import subprocess
import PyInstaller.__main__

# Initialize constants
SCRIPT = "cod_api_tool.py"
NAME = "cod_api_tool"
DIST_PATH = os.path.join("bin", "build")
ICON_WIN = "assets/icon.ico"
ICON_LINUX = "assets/icon.png"  # Linux uses .png for icons

# Get absolute paths to data files
script_dir = os.path.abspath(os.path.dirname(__file__))
charset_normalizer_data = os.path.join('deps', 'frequencies.json')
replacements_json = os.path.join(script_dir, 'data', 'replacements.json')

# Verify replacements.json exists before building
if not os.path.exists(replacements_json):
    print(f"ERROR: {replacements_json} not found. Make sure this file exists.")
    sys.exit(1)

# Determine system platform
is_windows = sys.platform == 'win32'

# Activate the virtual environment
if is_windows:
    venv_activation_script = os.path.join(os.getcwd(), 'venv', 'Scripts', 'activate')
else:
    venv_activation_script = os.path.join(os.getcwd(), 'venv', 'bin', 'activate')

# Use the correct icon based on platform
ICON = ICON_WIN if is_windows else ICON_LINUX

# Construct PyInstaller command
pyinstaller_args = [
    SCRIPT,
    '--name', NAME,
    '--noconfirm',
    '--onefile',
    '--console',
    '--distpath', DIST_PATH,
    '--add-data', f"{charset_normalizer_data}{os.pathsep}charset_normalizer/assets",
    '--add-data', f"{replacements_json}{os.pathsep}data",
]

# Add icon only if it exists
if os.path.exists(ICON):
    pyinstaller_args.extend(['--icon', ICON])

# Run PyInstaller
PyInstaller.__main__.run(pyinstaller_args)

# Clean up build directory and spec file
shutil.rmtree('build')
os.remove(f'{NAME}.spec')

# Notify user where the output is
executable_name = f"{NAME}.exe" if is_windows else NAME
print(f"Build completed successfully. Executable is in {DIST_PATH}/{executable_name}")
